Learn R Programming

EpiEstim (version 1.1-0)

OverallInfectivity: Overall Infectivity Due To Previously Infected Individuals

Description

OverallInfectivity computes the overall infectivity due to previously infected individuals.

Usage

OverallInfectivity(I, SI.Distr)

Arguments

I
vector of non-negative integers containing an incidence time series.
SI.Distr
vector of probabilities giving the discrete distribution of the serial interval.

Value

  • OverallInfectivity(I, SI.Distr) returns a vector which contains the overall infectivity $\lambda_t$ at each time step $t$.

encoding

UTF-8

Details

The overall infectivity $\lambda_t$ at time step $t$ is equal to the sum of the previously infected individuals (given by the incidence vector $I$), weigthed by their infectivity at time $t$ (given by the discrete serial interval distribution $w_k$). In mathematical terms: $\lambda_t = \sum_{k=1}^{t-1}I_{t-k}w_k$

References

Cori, A. et al. A new framework and software to estimate time-varying reproduction numbers during epidemics. (submitted)

See Also

DiscrSI, EstimateR

Examples

Run this code
## load data on pandemic flu in a school in 2009
data("Flu2009")

## compute overall infectivity
lambda <- OverallInfectivity(Flu2009$Incidence, Flu2009$SI.Distr)
par(mfrow=c(2,1))
plot(Flu2009$Incidence, type="s", xlab="time (days)", ylab="Incidence")
title(main="Epidemic curve")
plot(lambda, type="s", xlab="time (days)", ylab="Infectivity")
title(main="Overall infectivity")

Run the code above in your browser using DataLab