Set default for MCMC control
Value
a list of default MCMC control parameters, containing:
n_iter: the number of iterations for the MCMC to performburnin: the burnin to use; MCMC iterations will only be recorded after the burninthin: MCMC iterations will only be recorded after the burnin and everythiniteration
Values can then be manually edited as in the examples below.